@@ -679,7 +679,7 @@ Public License instead of this License.  But first, please read
 
 MESSAGE = '''
 Python-Extension
-Version : 1.3.2
+Version : 1.3.3
 Author : Yile Wang
 Copyright : Yile Wang
 License : GNU General Public License
@@ -695,7 +695,7 @@ It is divided into pyextension and tkextension,
 tkextension is particularly powerful. 
 
 
-Pyextension
+Pyextensionass
 
 Pyextension includes main modules
 (open source function, computer information function),
@@ -709,6 +709,7 @@ Tkextense includes dialog window,tix widget,
 quick generation of Tkinter object,
 quick document processing (open and save as),
 open source module,
+tix module, ttk module,
 small blackboard module, turtle graphics drawing module and timer module
 '''
 
