@@ -1,3 +1,5 @@
+# -*- coding=utf-8 -*-
+
 import sys
 if sys.version_info[0] != 3 or sys.version_info[1] < 6:
     raise SystemExit('This module needs Python 3.6 or more later')
@@ -9,13 +11,45 @@ from tkextension.value import *
 import pickle
 import time
 
-class Layout():
-    def pack(self, **kw):
-        self.frame.pack(**kw)
-    def grid(self, **kw):
-        self.frame.grid(**kw)
-    def place(self, **kw):
-        self.frame.place(**kw)
+class Pack():
+    def pack(self, **options):
+        return self.frame.pack(**options)
+    def pack_forget(self):
+        return self.frame.pack_forget()
+    def pack_info(self):
+        return self.frame.pack_info(self)
+
+class Grid():
+    def grid(self, **options):
+        return self.frame.grid(**options)
+    def grid_forget(self):
+        return self.frame.grid_forget()
+    def grid_info(self):
+        return self.frame.pack_info(self)
+    def grid_bbox(self, column=None, row=None, col2=None, row2=None):
+        return self.frame.grid_bbox(column, row, col2, row2)
+    def grid_columnconfigure(self, index, **options):
+        return self.frame.grid_columnconfigure(index, **options)
+    def grid_rowconfigure(self, index, **options):
+        return self.frame.grid_rowconfigure(index, **options)
+    def grid_location(self, x, y):
+        return self.frame.grid_location(x, y)
+    def grid_remove(self):
+        return self.frame.grid_remove()
+    def grid_size(self):
+        return self.frame.grid_size()
+
+class Place():
+    def place(self, **options):
+        return self.frame.place(**options)
+    def place_forget(self):
+        return self.frame.forget()
+    def place_info(self):
+        return self.frame.pack_info(self)
+
+class Layout(Pack, Grid, Place):
+    def forget(self):
+        return self.frame.forget()
 
 class AskValue(Layout):
     def __init__(self, tkinter_attribute, msg='', args=(0, 100), get=False):
@@ -23,7 +57,8 @@ class AskValue(Layout):
         self.frame = Frame(self.tk)
         # Tkinter
         if msg != '':
-            Label(self.frame, text=msg).pack()
+            self.label = Label(self.frame, text=msg)
+            self.label.pack()
         if type(args[0]) == type(0):
             self.sb = Scale(self.frame, from_=args[0], to=args[1], orient='horizontal')
         elif type(args[0]) == type('0'):
@@ -34,6 +69,12 @@ class AskValue(Layout):
         if get == True:
             Button(self.frame, text='OK', command=self.get).pack()
         # Window
+    def config(self, msg=''):
+        if msg != '':
+            self.label = Label(self.frame, text=msg)
+            self.label.pack()
+        else:
+            self.label.forget()
     def get(self):
         return self.sb.get()
 
@@ -47,7 +88,8 @@ class AskItem(Layout):
         self.frame = Frame(self.tk)
         # Tkinter
         if msg != '':
-            Label(self.frame, text=msg).place(relx=0.5, rely=0.05, relwidth=1, relheight=0.1, anchor='center')#, selectmode='multiple')
+            self.label = Label(self.frame, text=msg)
+            self.label.place(relx=0.5, rely=0.05, relwidth=1, relheight=0.1, anchor='center')
         self.lb = Listbox(self.frame)
         self.lb.pack()
         self.lb.selection_set(normal)
@@ -57,6 +99,12 @@ class AskItem(Layout):
         for x in range(0, len(items)):
             self.lb.insert('end', items[x])
         # Load
+    def config(self, msg=''):
+        if msg != '':
+            self.label = Label(self.frame, text=msg)
+            self.label.pack()
+        else:
+            self.label.forget()
     def get(self):
         finish = False
         get = []
@@ -76,12 +124,19 @@ class AskAnswer(Layout):
         self.frame = Frame(self.tk)
         # Tkinter
         if msg != '':
-            Label(self.frame, text=msg).pack()
+            self.label = Label(self.frame, text=msg)
+            self.label.pack()
         self.entry = Entry(self.frame, width=30)
         self.entry.pack()
         if get == True:
             Button(self.frame, text='Finish', command=self.get).pack()
         # Window
+    def config(self, msg=''):
+        if msg != '':
+            self.label = Label(self.frame, text=msg)
+            self.label.pack()
+        else:
+            self.label.forget()
     def get(self):
         return self.entry.get()
 
@@ -144,7 +199,8 @@ class SingleChoice(Layout):
         self.frame = Frame(self.tk)
         # Tkinter
         if msg != '':
-            Label(self.frame, text=msg).pack()
+            self.label = Label(self.frame, text=msg)
+            self.label.pack()
         window = []
         self.v = StringVar()
         for x in args:
@@ -154,6 +210,12 @@ class SingleChoice(Layout):
         if get == True:
             Button(self.frame, text='Finish', command=self.get).pack()
         # Window
+    def config(self, msg=''):
+        if msg != '':
+            self.label = Label(self.frame, text=msg)
+            self.label.pack()
+        else:
+            self.label.forget()
     def get(self):
         return self.v.get()
 
@@ -163,7 +225,8 @@ class SingleChoices(Layout):
         self.frame = Frame(self.tk)
         # Tkinter
         if msg != '':
-            Label(self.frame, text=msg).pack()
+            self.label = Label(self.frame, text=msg)
+            self.label.pack()
         # Label
         self.value_list = []
         lf_list = []
@@ -183,6 +246,12 @@ class SingleChoices(Layout):
             Button(tk, text='Finish', command=self.get).pack()
         # Button
         # Window
+    def config(self, msg=''):
+        if msg != '':
+            self.label = Label(self.frame, text=msg)
+            self.label.pack()
+        else:
+            self.label.forget()
     def get(self):
         get = []
         for x in self.value_list:
@@ -198,7 +267,8 @@ class AnswerSheet(Layout):
         self.frame = Frame(self.tk)
         # Tkinter
         if msg != '':
-            Label(self.frame, text=msg).pack()
+            self.label = Label(self.frame, text=msg)
+            self.label.pack()
         # Label
         self.value_list = []
         lf_list = []
@@ -218,6 +288,12 @@ class AnswerSheet(Layout):
             Button(self.frame, text='Finish', command=self.get).pack()
         # Button
         # Window
+    def config(self, msg=''):
+        if msg != '':
+            self.label = Label(self.frame, text=msg)
+            self.label.pack()
+        else:
+            self.label.forget()
     def get(self):
         get = []
         for x in self.value_list:
